@@ -14,14 +14,14 @@ Chj::time_this - benchmarking function that also returns the result(s)
 =head1 SYNOPSIS
 
     use Chj::tim;
-    my $res= time_this { somefunc(66) }; # prints timing to stderr
+    my $res = time_this { somefunc(66) }; # prints timing to stderr
     # or
-    my $res= time_this { somefunc(66) } "somefunc"; # included in message
+    my $res = time_this { somefunc(66) } "somefunc"; # included in message
     # or
-    my $res= time_this { somefunc(66) }
-                 msg=> "somefunc", n=> 10; # run thunk 10 times
+    my $res = time_this { somefunc(66) }
+                 msg => "somefunc", n => 10; # run thunk 10 times
     # or
-    my $res= time_this { somefunc(66) } out=> \@t; # push to @t instead of stderr
+    my $res = time_this { somefunc(66) } out => \@t; # push to @t instead of stderr
 
 =head1 DESCRIPTION
 
@@ -46,39 +46,41 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package Chj::time_this;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(time_this);
-@EXPORT_OK=qw();
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT      = qw(time_this);
+our @EXPORT_OK   = qw();
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
-my $fields= [qw(user system cuser csystem)];
+my $fields = [qw(user system cuser csystem)];
 
 sub time_this (&;@) {
-    my ($thunk,@args)=@_;
-    my $wantarray= wantarray;
-    my $args={};
-    my $maybe_msg= @args==1 ? $args[0] : do { $args= +{@args}; $$args{msg} };
-    my $n= $$args{n} // 1;
+    my ($thunk, @args) = @_;
+    my $wantarray = wantarray;
+    my $args      = {};
+    my $maybe_msg
+        = @args == 1 ? $args[0] : do { $args = +{@args}; $$args{msg} };
+    my $n = $$args{n} // 1;
 
-    my $a= [times];
+    my $a = [times];
     my @res;
-    for (1..$n) {
-        @res= $wantarray ? &$thunk() : scalar &$thunk();
+    for (1 .. $n) {
+        @res = $wantarray ? &$thunk() : scalar &$thunk();
     }
-    my $b= [times];
+    my $b = [times];
 
-    my $d= [map { $$fields[$_]."=".($$b[$_] - $$a[$_]) } 0..$#$a ];
-    my $forstr= defined($maybe_msg) ? " for $maybe_msg" : "";
-    my $msgstr= "times$forstr: ".join(", ",@$d)."\n";
-    if (my $out= $$args{out}) {
-        if (ref ($out) eq "ARRAY") {
+    my $d      = [map { $$fields[$_] . " = " . ($$b[$_] - $$a[$_]) } 0 .. $#$a];
+    my $forstr = defined($maybe_msg) ? " for $maybe_msg" : "";
+    my $msgstr = "times$forstr: " . join(", ", @$d) . "\n";
+    if (my $out = $$args{out}) {
+        if (ref($out) eq "ARRAY") {
             push @$out, $msgstr
-        } elsif (ref ($out) eq "SCALAR") {
-            $$out= $msgstr
+        } elsif (ref($out) eq "SCALAR") {
+            $$out = $msgstr
         } elsif (is_filehandle $out) {
             print $out $msgstr
         } else {
@@ -90,5 +92,4 @@ sub time_this (&;@) {
     $wantarray ? @res : $res[0]
 }
 
-
 1
