@@ -288,7 +288,7 @@ BEGIN {
 }
 
 sub xfork {
-    @_ == 0 or fp_croak_nargs 0;
+    @_ == 0 or fp_croak_arity 0;
     my $pid = fork;
     defined $pid or croak "xfork: $!";
     $pid
@@ -296,7 +296,7 @@ sub xfork {
 
 # thread-like API; incomplete, for sure.
 sub xfork_(&) {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($thunk) = @_;
     my $pid = xfork;
     if ($pid) {
@@ -398,7 +398,7 @@ sub xxsystem_safe {
 }
 
 sub xwaitpid {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($pid, $flags) = @_;
     defined $flags or $flags = 0;
     my $kid = waitpid $pid, $flags;
@@ -410,7 +410,7 @@ sub xwaitpid {
 }
 
 sub xxwaitpid {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($pid, $flags) = @_;
     defined $flags or $flags = 0;
     my $kid = xwaitpid $pid, $flags;
@@ -421,14 +421,14 @@ sub xxwaitpid {
 }
 
 sub xwait {
-    @_ == 0 or fp_croak_nargs 0;
+    @_ == 0 or fp_croak_arity 0;
     my $kid = wait;
     defined $kid or die "xwait: $!";    # when can this happen? EINTR?
     wantarray ? ($kid, $?) : $kid
 }
 
 sub xxwait {
-    @_ == 0 or fp_croak_nargs 0;
+    @_ == 0 or fp_croak_arity 0;
     my $kid = wait;
     defined $kid or die "xxwait: $!";    # when can this happen? EINTR?
     my $status = $?;
@@ -438,12 +438,12 @@ sub xxwait {
 }
 
 sub xrename {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     rename $_[0], $_[1] or croak "xrename(" . join(", ", @_) . "): $!";
 }
 
 sub xlinkunlink {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     link $_[0], $_[1]
         or croak "xlinkunlink("
         . join(", ", @_)
@@ -470,7 +470,7 @@ sub xlinkunlink {
 # Since xlinkunlink doesn't work for directories, or not always under
 # grsec: (But note: it's careful, not guaranteed to be safe.)
 sub xxcarefulrename {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($source, $dest) = @_;
     if (link $source, $dest) {
         unlink $source or do {
@@ -510,7 +510,7 @@ sub xxcarefulrename {
 }
 
 sub xlinkreplace {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($source, $dest) = @_;
     ## schon wieder dieser temporary try mechanismus. sollte ich dringend eine generische func oder ein makro dafür haben theoretisch
 # nun im gegensatz zu Tempfile.pm brauchen wir kein eval hier. Aber auch das waer ja per func/macro machbar
@@ -570,14 +570,14 @@ sub stat_possiblyhires {
     if ($time_hires) {
         require Time::HiRes;    # (that's not slow, right?)
         if (@_) {
-            @_ == 1 or fp_croak_nargs 1;
+            @_ == 1 or fp_croak_arity 1;
             Time::HiRes::stat($_[0])
         } else {
             Time::HiRes::stat($_)
         }
     } else {
         if (@_) {
-            @_ == 1 or fp_croak_nargs 1;
+            @_ == 1 or fp_croak_arity 1;
             stat($_[0])
         } else {
             stat($_)
@@ -589,14 +589,14 @@ sub lstat_possiblyhires {
     if ($time_hires) {
         require Chj::Linux::HiRes;
         if (@_) {
-            @_ == 1 or fp_croak_nargs 1;
+            @_ == 1 or fp_croak_arity 1;
             Chj::Linux::HiRes::lstat($_[0])
         } else {
             Chj::Linux::HiRes::lstat($_)
         }
     } else {
         if (@_) {
-            @_ == 1 or fp_croak_nargs 1;
+            @_ == 1 or fp_croak_arity 1;
             lstat($_[0])
         } else {
             lstat($_)
@@ -681,7 +681,7 @@ sub mk_caching_getANYid {
     my ($function, $scalarindex, $methodname) = @_;
     my %cache;
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($id) = @_;
         if (defined $id) {
             my $v;
@@ -708,7 +708,7 @@ sub mk_caching_getANYid {
 our $fstype_for_device;
 
 sub fstype_for_device_init {
-    @_ == 0 or fp_croak_nargs 0;
+    @_ == 0 or fp_croak_arity 0;
     open my $mounts, "<", "/proc/mounts" or die "/proc/mounts: $!";
     local $/ = "\n";
     my %t;
@@ -753,7 +753,7 @@ sub fstype_for_device_init {
 }
 
 sub fstype_for_device {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($dev) = @_;
     my $t = $fstype_for_device->{$dev};
     if (!defined $t) {
@@ -1046,7 +1046,7 @@ use FP::Div qw(min max);    # min just for the backwards-compatible
 }
 
 sub XLmtimed {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     if (my $ls = Xlstat $path) {
         bless do {
@@ -1066,20 +1066,20 @@ sub XLmtimed {
 }
 
 sub xLmtimed {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     my $t = XLmtimed $path;
     (defined $t) ? $t : die "xLmtimed: '$path': $!"
 }
 
 sub xLmtime {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     xLmtimed($path)->mtime
 }
 
 sub XLmtime {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     if (defined(my $s = XLmtimed($path))) {
         $s->mtime
@@ -1128,7 +1128,7 @@ sub XLmtime {
 }
 
 sub xlocaltime {
-    @_ >= 0 and @_ <= 1 or fp_croak_nargs "0-1";
+    @_ >= 0 and @_ <= 1 or fp_croak_arity "0-1";
     bless [localtime(defined $_[0] ? $_[0] : time)],
         "Chj::xperlfunc::xlocaltime"
 }
@@ -1213,17 +1213,17 @@ sub xunlink {
 }
 
 sub xlink {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     link $_[0], $_[1] or croak "xlink '$_[0]','$_[1]': $!";
 }
 
 sub xsymlink {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     symlink $_[0], $_[1] or croak "xsymlink to '$_[1]': $!";
 }
 
 sub xutime {
-    @_ >= 2 or fp_croak_nargs ">= 2";
+    @_ >= 2 or fp_croak_arity ">= 2";
     my ($atime, $mtime) = (shift, shift);
     utime $atime, $mtime, @_ or croak "xutime @_: $!";
 }
@@ -1234,7 +1234,7 @@ sub xkill {
 }
 
 sub xchroot {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($rtd) = @_;
     chroot $rtd or die "could not chroot to '$rtd': $!";
 }
@@ -1277,7 +1277,7 @@ sub xfileno {
 }
 
 sub xsysread {
-    @_ >= 3 and @_ <= 4 or fp_croak_nargs "3-4";
+    @_ >= 3 and @_ <= 4 or fp_croak_arity "3-4";
     my $rv = do {
         if (@_ == 4) {
             sysread $_[0], $_[1], $_[2], $_[3]
@@ -1295,7 +1295,7 @@ sub xsysread {
 use FP::Show qw(show_many);
 
 sub basename {
-    @_ >= 1 and @_ <= 3 or fp_croak_nargs "1-3";
+    @_ >= 1 and @_ <= 3 or fp_croak_arity "1-3";
     my ($path, $maybe_suffixS, $insensitive) = @_;
     my $copy = $path;
     $copy =~ s|.*/||s;
@@ -1352,7 +1352,7 @@ sub basename {
 # so no, do not strip before basenaming, really do it afterwards as I do
 
 sub dirname {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     if ($path =~ s|/+[^/]+/*\z||) {
         if (length $path) {
@@ -1378,7 +1378,7 @@ sub dirname {
 sub xmkdir_p;
 
 sub xmkdir_p {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
 
     # (XX: see commit d1abd3c2 in megacopy for possible improvement)
@@ -1403,7 +1403,7 @@ sub xmkdir_p {
 }
 
 sub xlink_p {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($from, $to) = @_;
     xmkdir_p(dirname $to);
     xlink $from, $to
@@ -1436,7 +1436,7 @@ sub xlink_p {
 }
 
 sub xgetpwnam {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($user) = @_;
     if (wantarray) {
         my @f = Chj::xperlfunc::Getpwnam->perhaps_get($user);
@@ -1467,7 +1467,7 @@ sub xgetpwnam {
 }
 
 sub xgetgrnam {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($group) = @_;
     if (wantarray) {
         my @f = Chj::xperlfunc::Getgrnam->perhaps_get($group);
@@ -1494,7 +1494,7 @@ sub xprintln {
 }
 
 sub xgetfile_utf8 {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($path) = @_;
     open my $in, "<", $path or die "xgetfile_utf8($path): open: $!";
     binmode $in, ":encoding(UTF-8)" or die "binmode";
