@@ -90,30 +90,30 @@ sub array_sort {
 }
 
 sub array_sortCompare {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($in) = @_;
     [sort { $a->FP_Compare_compare($b) } @$in]
 }
 
 sub on {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($select, $cmp) = @_;
     sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($a, $b) = @_;
         &$cmp(&$select($a), &$select($b))
     }
 }
 
 sub on_maybe {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($maybe_select, $cmp) = @_;
     defined $maybe_select ? on($maybe_select, $cmp) : $cmp
 }
 
 # see also `complement` from FP::Predicates
 sub cmp_complement {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($cmp) = @_;
     sub {
         -&$cmp(@_)
