@@ -214,18 +214,18 @@ package FP::List::List {
 
     # return this sequence as a list, i.e. identity
     sub list {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         $_[0]
     }
 
     sub stream {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($l) = @_;
         lazy {$l}
     }
 
     sub strictlist {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $s = shift;
         FP::StrictList::strictlist($s->values)
     }
@@ -233,7 +233,7 @@ package FP::List::List {
     # sub purearray: see below, *FP::List::List::purearray
 
     sub mutablearray {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my $s = shift;
         FP::_::MutableArray->new_from_array([$s->values])
     }
@@ -256,7 +256,7 @@ package FP::List::Null {
 
     sub cons {
         my $s = shift;
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my @p = ($_[0], $s);
         bless \@p, $s->pair_namespace;
         if ($immutable) {
@@ -310,7 +310,7 @@ package FP::List::Pair {
 
     sub cons {
         my $s = shift;
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my @p = ($_[0], $s);
         bless \@p, ref($s);
         if ($immutable) {
@@ -408,7 +408,7 @@ TEST {
 1;
 
 sub cons {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     if (defined blessed($_[1]) and my $f = $_[1]->can("cons")) {
         @_ = ($_[1], $_[0]);
         goto &$f;
@@ -418,10 +418,10 @@ sub cons {
 }
 
 sub cons_ {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($item) = @_;
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         if (defined blessed($_[0]) and my $f = $_[0]->can("cons")) {
             push @_, $item;
             goto &$f;
@@ -435,7 +435,7 @@ TEST { cons_(1)->(list(2)) } GIVES { list(1, 2) };
 TEST { cons_(1)->(2) } GIVES       { cons 1, 2 };
 
 sub pair {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     goto \&unsafe_cons
 }
 
@@ -446,7 +446,7 @@ sub pair {
 # the rest argument should never dictate the type of the result.
 
 sub unsafe_cons {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my @p = @_;
     bless \@p, "FP::List::Pair";
     if ($immutable) {
@@ -460,18 +460,18 @@ sub unsafe_cons {
 # WARNING: be careful, this isn't safe even if `is_pair` returns true, as
 # that only assures that ->car etc. can be called.
 sub unsafe_car {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0][0]
 }
 
 # WARNING: same as for unsafe_car
 sub unsafe_cdr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0][1]
 }
 
 sub is_pair {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     (
@@ -484,7 +484,7 @@ sub is_pair {
 }
 
 sub is_pair_noforce {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     ($r eq "FP::List::Pair" or $v->isa("FP::List::Pair"))
@@ -493,7 +493,7 @@ sub is_pair_noforce {
 sub is_pair_of {
     my ($p0, $p1) = @_;
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($v) = @_;
         (is_pair($v) and &$p0($$v[0]) and &$p1($$v[1]))
     }
@@ -511,7 +511,7 @@ Internals::SvREADONLY $null, 1;
 
 sub null () {
 
-    # @_ == 0 or fp_croak_nargs 0;
+    # @_ == 0 or fp_croak_arity 0;
     # nope, it is also called as a method
     $null
 }
@@ -520,7 +520,7 @@ TEST { null->cons(1)->cons(2)->array }
 [2, 1];
 
 sub is_null {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     (
@@ -531,14 +531,14 @@ sub is_null {
 }
 
 sub is_null_noforce {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     ($r eq "FP::List::Null" or $v->isa("FP::List::Null"))
 }
 
 sub is_pair_or_null {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // return;
     (
@@ -556,18 +556,18 @@ TEST { is_pair_or_null bless [], "NirvAna" } '';
 # test subclassing? whatever
 
 sub is_null_or_pair_of {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($v, $p0, $p1) = @_;
     FORCE $v;
     (is_null $v or (is_pair $v and &$p0($v->car) and &$p1($v->cdr)))
 }
 
 sub null_or_pair_of {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($p0, $p1) = @_;
 
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($v) = @_;
         is_null_or_pair_of($v, $p0, $p1)
     }
@@ -590,7 +590,7 @@ TEST {
 [1, undef, undef, '', 1, ''];
 
 sub is_list {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     FORCE $v;
     (
@@ -618,13 +618,13 @@ TEST {
 '';
 
 sub die_not_a_pair {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     croak "not a pair: " . show($v);
 }
 
 sub car {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // die_not_a_pair($v);
     if ($r eq "FP::List::Pair") {
@@ -644,7 +644,7 @@ sub first;
 # be more structured/automatic, finally.
 
 sub first_set {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($p, $v) = @_;
     cons($v, $p->rest)
 }
@@ -652,7 +652,7 @@ sub first_set {
 TEST { cons(3, 4)->first_set("a") } bless ["a", 4], 'FP::List::Pair';
 
 sub first_update {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($p, $fn) = @_;
     my ($v, $r)  = $p->first_and_rest;
     cons(&$fn($v), $r)
@@ -664,7 +664,7 @@ TEST {
 bless [6, 4], 'FP::List::Pair';
 
 sub cdr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // die_not_a_pair($v);
     if ($r eq "FP::List::Pair") {
@@ -687,42 +687,42 @@ sub rest;
 *rest = \&cdr;
 
 sub cddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     cdr cdr $_[0]
 }
 
 sub cdddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     cdr cdr cdr $_[0]
 }
 
 sub cddddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     cdr cdr cdr cdr $_[0]
 }
 
 sub cadr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     car cdr $_[0]
 }
 
 sub caddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     car cdr cdr $_[0]
 }
 
 sub cadddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     car cdr cdr cdr $_[0]
 }
 
 sub caddddr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     car cdr cdr cdr cdr $_[0]
 }
 
 sub c_r {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($s, $chain) = @_;
     my $c;
     while (length($c = chop $chain)) {
@@ -740,7 +740,7 @@ TEST { list(1, list(4, 7, 9), 5)->c_r("addad") }
 9;
 
 sub car_and_cdr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // die_not_a_pair($v);
     if ($r eq "FP::List::Pair") {
@@ -757,7 +757,7 @@ sub first_and_rest;
 *first_and_rest = \&car_and_cdr;
 
 sub perhaps_first_and_rest {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     my $r = blessed($v) // die_not_a_pair($v);
     if ($r eq "FP::List::Pair") {
@@ -780,7 +780,7 @@ TEST_EXCEPTION { [perhaps_first_and_rest "FP::List::Null"] }
 "not a pair: 'FP::List::Null'";    # and XX actually not a null either.
 
 sub list_perhaps_one {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($s) = @_;
     FORCE $s;                      # make work for stre
     if (is_pair($s)) {
@@ -799,7 +799,7 @@ TEST { [list(8, 9)->perhaps_one] } [];
 TEST { [list()->perhaps_one] } [];
 
 sub list_xone {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($s) = @_;
     FORCE $s;    # make work for streams
     if (is_pair($s)) {
@@ -825,7 +825,7 @@ sub make_ref {
     my $liststream = $is_stream ? "stream" : "list";
 
     sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($s, $i) = @_;
         weaken $_[0] if $is_stream;
         is_natural0 $i or fp_croak "invalid index: " . show($i);
@@ -951,7 +951,7 @@ TEST_EXCEPTION {
 'improper list';    # nice message at least, thanks to undef != null
 
 sub delayed (&) {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($thunk) = @_;
     sub {
         # evaluate thunk, expecting a function and pass our arguments
@@ -962,7 +962,7 @@ sub delayed (&) {
 }
 
 sub list_of {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($p) = @_;
     either \&is_null, is_pair_of($p, delayed { list_of($p) })
 }
@@ -977,7 +977,7 @@ sub make_length {
     my $liststream = $is_stream ? "stream" : "list";
 
     sub {
-        @_ == 1 or fp_croak_nargs 1;
+        @_ == 1 or fp_croak_arity 1;
         my ($l) = @_;
         weaken $_[0] if $is_stream;
         my $len = 0;
@@ -1012,7 +1012,7 @@ TEST { list()->length } 0;
 TEST { list(4, 5)->length } 2;
 
 sub list_to_string {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     my $len = list_length $l;
 
@@ -1038,7 +1038,7 @@ TEST { list("", "", "o")->string } 'o';
 TEST { list("a", "", "o")->string } 'ao';
 
 sub list_to_array {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     my $res = [];
     my $i   = 0;
@@ -1053,7 +1053,7 @@ sub list_to_array {
 *FP::List::List::array = \&list_to_array;
 
 sub list_to_purearray {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     my $a = list_to_array $l;
     require FP::PureArray;
@@ -1068,7 +1068,7 @@ TEST {
 bless [1, 9, 16], "FP::_::PureArray";
 
 sub list_sort {
-    @_ == 1 or @_ == 2 or fp_croak_nargs "1 or 2";
+    @_ == 1 or @_ == 2 or fp_croak_arity "1 or 2";
     my ($l, $maybe_cmp) = @_;
     list_to_purearray($l)->sort ($maybe_cmp)
 }
@@ -1076,7 +1076,7 @@ sub list_sort {
 *FP::List::List::sort = \&list_sort;
 
 sub list_sortCompare {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     list_to_purearray($l)->sortCompare
 }
@@ -1103,7 +1103,7 @@ TEST { list(5, 3, 8, 4)->sort (\&FP::Ops::number_cmp)->stream->car }
 3;
 
 sub rlist_to_array {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     my $res = [];
     my $len = list_length $l;
@@ -1119,7 +1119,7 @@ sub rlist_to_array {
 *FP::List::List::reverse_array = \&rlist_to_array;
 
 sub list_to_values {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     @{ list_to_array($l) }
 }
@@ -1129,7 +1129,7 @@ sub list_to_values {
 # XX naming inconsistency versus docs/design.md ? Same with
 # rlist_to_array.
 sub rlist_to_values {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     @{ rlist_to_array($l) }
 }
@@ -1144,7 +1144,7 @@ sub make_for_each {
     my $liststream = $is_stream ? "stream" : "list";
 
     sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($proc, $s) = @_;
         weaken $_[1] if $is_stream;
     LP: {
@@ -1180,7 +1180,7 @@ TEST_STDOUT {
 # solution for this
 
 sub list_drop {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($s, $n) = @_;
     while ($n > 0) {
         $s = force $s;
@@ -1194,7 +1194,7 @@ sub list_drop {
 *FP::List::List::drop = \&list_drop;
 
 sub list_take {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($s, $n) = @_;
     if ($n > 0) {
         $s = force $s;
@@ -1207,7 +1207,7 @@ sub list_take {
 *FP::List::List::take = \&list_take;
 
 sub list_slice {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($start, $end) = @_;
     $end = force $end;
     my $rec;
@@ -1236,7 +1236,7 @@ sub list_slice {
 # /COPIES
 
 sub string_to_list {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($str, $maybe_tail) = @_;
     my $tail = $maybe_tail // null;
     my $i    = length($str) - 1;
@@ -1256,7 +1256,7 @@ TEST { list_to_string string_to_list "Hello" }
 
 # XX HACK, COPY from FP::Array to work around circular dependency
 sub array_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $tail, $a) = @_;
     my $i = @$a - 1;
     while ($i >= 0) {
@@ -1267,7 +1267,7 @@ sub array_fold_right {
 }
 
 sub array_fold {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $ary) = @_;
     for (@$ary) {
         $start = &$fn($_, $start);
@@ -1278,7 +1278,7 @@ sub array_fold {
 # /HACK
 
 sub array_to_list {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($a, $maybe_tail) = @_;
     array_fold_right(\&cons, $maybe_tail // null, $a)
 }
@@ -1288,7 +1288,7 @@ TEST { list_to_string array_to_list [1, 2, 3] }
 
 # XX naming correct?
 sub array_to_list_reverse {
-    @_ >= 1 and @_ <= 2 or fp_croak_nargs "1-2";
+    @_ >= 1 and @_ <= 2 or fp_croak_arity "1-2";
     my ($a, $maybe_tail) = @_;
     array_fold(\&cons, $maybe_tail // null, $a)
 }
@@ -1297,7 +1297,7 @@ TEST { list_to_string array_to_list_reverse [1, 2, 3] }
 '321';
 
 sub list_reverse_with_tail {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $tail) = @_;
     while (!is_null $l) {
         $tail = cons car($l), $tail;
@@ -1307,7 +1307,7 @@ sub list_reverse_with_tail {
 }
 
 sub list_reverse {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     list_reverse_with_tail($l, $l->null)
 }
@@ -1319,7 +1319,7 @@ TEST { list_to_string list_reverse string_to_list "Hello" }
 'olleH';
 
 sub list_strings_join {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $val) = @_;
 
     # now depend on FP::Array anyway. Lazily. XX hack~
@@ -1333,7 +1333,7 @@ TEST { list(1, 2, 3)->strings_join("-") }
 "1-2-3";
 
 sub list_strings_join_reverse {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $val) = @_;
 
     # now depend on FP::Array anyway. Lazily. XX hack~
@@ -1348,7 +1348,7 @@ TEST { list(1, 2, 3)->strings_join_reverse("-") }
 
 # write as a S-expr (trying to follow R5RS Scheme)
 sub _write_sexpr {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($l, $fh, $already_in_a_list) = @_;
 _WRITE_SEXPR: {
         $l = force($l, 1);
@@ -1388,7 +1388,7 @@ _WRITE_SEXPR: {
 }
 
 sub write_sexpr {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l, $fh) = @_;
     _write_sexpr($l, $fh || *STDOUT{IO}, 0)
 }
@@ -1409,7 +1409,7 @@ TEST_STDOUT { write_sexpr cons(1, cons(cons(2, null), null)) }
 *FP::List::List::write_sexpr = \&write_sexpr;
 
 sub list_zip2 {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($l, $m) = @_;
     (     is_null($l) ? $l
         : is_null($m) ? $m
@@ -1425,7 +1425,7 @@ TEST { list_to_array list_zip2 list(qw(a b)), list(2, 3, 4) }
 *FP::List::List::zip = \&list_zip2;    # XX make n-ary
 
 sub list_to_alist {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     is_null($l) ? $l : do {
         my ($k, $l2) = $l->first_and_rest;
@@ -1442,7 +1442,7 @@ sub make_filter {
     my ($is_stream) = @_;
     my $filter;
     $filter = sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($fn, $l) = @_;
         weaken $_[1] if $is_stream;
         lazy_if {
@@ -1469,7 +1469,7 @@ sub make_filter_with_tail {
     my ($is_stream) = @_;
     my $filter_with_tail;
     $filter_with_tail = sub {
-        @_ == 3 or fp_croak_nargs 3;
+        @_ == 3 or fp_croak_arity 3;
         my ($fn, $l, $tail) = @_;
         weaken $_[1] if $is_stream;
         lazy_if {
@@ -1490,7 +1490,7 @@ sub list_filter_with_tail;
 *FP::List::List::filter_with_tail = flip2of3 \&list_filter_with_tail;
 
 sub list_map {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     is_null($l) ? $l : cons(scalar &$fn(car $l), list_map($fn, cdr $l))
 }
@@ -1521,7 +1521,7 @@ TEST {
 [[1, 'a'], [2, 'b']];
 
 sub FP::List::List::map {
-    @_ >= 2 or fp_croak_nargs ">= 2";
+    @_ >= 2 or fp_croak_arity ">= 2";
     my $l  = shift;
     my $fn = shift;
     @_ ? list_mapn($fn, $l, @_) : list_map($fn, $l)
@@ -1538,12 +1538,12 @@ sub list_map_with_index_ {
 }
 
 sub list_map_with_index {
-    @_ >= 2 or fp_croak_nargs ">= 2";
+    @_ >= 2 or fp_croak_arity ">= 2";
     list_map_with_index_(0, @_)
 }
 
 sub FP::List::List::map_with_index {
-    @_ >= 2 or fp_croak_nargs ">= 2";
+    @_ >= 2 or fp_croak_arity ">= 2";
     my $l  = shift;
     my $fn = shift;
     list_map_with_index($fn, $l, @_)
@@ -1555,7 +1555,7 @@ TEST {
 [[0, 1], [1, 2], [2, 20]];
 
 sub list_map_with_islast {
-    @_ >= 2 or fp_croak_nargs ">= 2";
+    @_ >= 2 or fp_croak_arity ">= 2";
     my $fn      = shift;
     my @rest    = map { is_null($_) ? return null : rest $_ } @_;
     my $is_last = '';
@@ -1584,7 +1584,7 @@ TEST {
 # left fold, sometimes called `foldl` or `reduce`
 # (XX adapted copy from Stream.pm)
 sub list_fold {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $l) = @_;
     my $v;
 LP: {
@@ -1608,7 +1608,7 @@ TEST {
 9;
 
 sub list_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $l) = @_;
     if (is_pair $l) {
         no warnings 'recursion';
@@ -1631,7 +1631,7 @@ TEST {
 
 sub FP::List::List::fold_right {
     my $l = shift;
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $start) = @_;
     list_fold_right($fn, $start, $l)
 }
@@ -1644,7 +1644,7 @@ TEST {
 # same as fold_right but passes the whole list remainder instead of
 # only the car to the function
 sub list_pair_fold_right {
-    @_ == 3 or fp_croak_nargs 3;
+    @_ == 3 or fp_croak_arity 3;
     my ($fn, $start, $l) = @_;
     if (is_pair $l) {
         no warnings 'recursion';
@@ -1680,7 +1680,7 @@ TEST_STDOUT { list(5, 6, 9)->pair_fold_right(\&cons, null)->write_sexpr }
 # http://srfi.schemers.org/srfi-1/srfi-1.html#FoldUnfoldMap
 
 sub unfold {
-    @_ == 4 or @_ == 5 or fp_croak_nargs "4 or 5";
+    @_ == 4 or @_ == 5 or fp_croak_arity "4 or 5";
     my ($p, $f, $g, $seed, $maybe_tail_gen) = @_;
     &$p($seed)
         ? (defined $maybe_tail_gen ? &$maybe_tail_gen($seed) : null)
@@ -1693,7 +1693,7 @@ TEST { unfold(\&is_zero, \&inc, \&dec, 5, \&list)->array } [6, 5, 4, 3, 2, 0];
 # unfold-right p f g seed [tail] -> list
 
 sub unfold_right {
-    @_ == 4 or @_ == 5 or fp_croak_nargs "4 or 5";
+    @_ == 4 or @_ == 5 or fp_croak_arity "4 or 5";
     my ($p, $f, $g, $seed, $maybe_tail) = @_;
     my $tail = @_ == 5 ? $maybe_tail : null;
 LP: {
@@ -1737,7 +1737,7 @@ TEST { array_to_list(["a", "b"])->append(array_to_list([1, 2]))->array }
 ['a', 'b', 1, 2];
 
 sub list_to_perlstring {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     list_to_string cons(
         "'",
@@ -1763,7 +1763,7 @@ q{'Hello\'s'};
 *FP::List::List::perlstring = \&list_to_perlstring;
 
 sub list_butlast {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     if (is_null($l)) {
         die "butlast: got empty list"
@@ -1783,7 +1783,7 @@ TEST_EXCEPTION { list()->butlast->array }
 'can\'t take the butlast of the empty list';
 
 sub list_drop_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
     while (!is_null $l and &$pred(car $l)) {
         $l = cdr $l;
@@ -1810,7 +1810,7 @@ TEST {
 "o World";
 
 sub list_rtake_while_and_rest {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
     my $res = $l->null;
     my $c;
@@ -1824,7 +1824,7 @@ sub list_rtake_while_and_rest {
 *FP::List::List::rtake_while_and_rest = flip \&list_rtake_while_and_rest;
 
 sub list_rtake_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l)    = @_;
     my ($res,  $rest) = list_rtake_while_and_rest($pred, $l);
     $res
@@ -1839,7 +1839,7 @@ TEST {
 'Hello';
 
 sub list_take_while_and_rest {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l)    = @_;
     my ($rres, $rest) = list_rtake_while_and_rest($pred, $l);
     (list_reverse($rres), $rest)
@@ -1848,7 +1848,7 @@ sub list_take_while_and_rest {
 *FP::List::List::take_while_and_rest = flip \&list_take_while_and_rest;
 
 sub list_take_while {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l)    = @_;
     my ($res,  $rest) = list_take_while_and_rest($pred, $l);
     $res
@@ -1876,7 +1876,7 @@ TEST {
 "";
 
 sub list_last {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
 LIST_LAST: {
         my ($a, $r) = $v->first_and_rest;
@@ -1901,7 +1901,7 @@ TEST_EXCEPTION { list(qw())->last }
 # XX: add list_last_pair (see SRFI 1)
 
 sub list_every {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
 LP: {
         if (is_pair $l) {
@@ -1969,7 +1969,7 @@ TEST {
 [2, 0];
 
 sub list_any {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($pred, $l) = @_;
 LP: {
         if (is_pair $l) {
@@ -2009,7 +2009,7 @@ TEST {
 # carry `perhaps` in their name of this reason.
 
 sub list_perhaps_find_tail {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
 LP: {
         if (is_null $l) { () }
@@ -2035,7 +2035,7 @@ TEST { [list(3, 1, 37, -5)->perhaps_find_tail(\&is_even)] }
 [];
 
 sub list_perhaps_find {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     if (my ($l) = list_perhaps_find_tail($fn, $l)) {
         $l->car
@@ -2072,7 +2072,7 @@ TEST { [list(3, 1, 37, -5)->find_tail(\&is_even)] }
 sub make_group {
     my ($is_stream) = @_;
     my $group = sub {
-        @_ >= 2 and @_ <= 3 or fp_croak_nargs "2-3";
+        @_ >= 2 and @_ <= 3 or fp_croak_arity "2-3";
         my ($equal, $s, $maybe_tail) = @_;
         weaken $_[1] if $is_stream;
         lazy_if {
@@ -2119,7 +2119,7 @@ sub list_group;
 *list_group = make_group(0);
 
 sub FP::List::List::group {
-    @_ >= 2 and @_ <= 3 or fp_croak_nargs "2-3";
+    @_ >= 2 and @_ <= 3 or fp_croak_arity "2-3";
     my ($self, $equal, $maybe_tail) = @_;
     list_group($equal, $self, $maybe_tail)
 }
@@ -2136,7 +2136,7 @@ list(list(3), list(4, 4), list(5), list(6), list(8), list(5, 5));
 # lazily (i.e. provide a promise that will do the forcing and consing).
 
 sub mixed_flatten {
-    @_ >= 1 and @_ <= 3 or fp_croak_nargs "1-3";
+    @_ >= 1 and @_ <= 3 or fp_croak_arity "1-3";
     my ($v, $maybe_tail, $maybe_delay) = @_;
     my $tail = $maybe_tail // null;
 LP: {
@@ -2159,7 +2159,7 @@ LP: {
             } elsif (ref $v eq "ARRAY") {
                 @_ = (
                     sub {
-                        @_ == 2 or fp_croak_nargs 2;
+                        @_ == 2 or fp_croak_arity 2;
                         my ($v, $tail) = @_;
                         no warnings 'recursion';
 
@@ -2264,7 +2264,7 @@ TEST_STDOUT {
 use FP::Char 'is_char';
 
 sub is_charlist {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($l) = @_;
     list_every \&is_char, $l
 }
